#!/usr/bin/env python3
# coding: utf-8

"""
Deprecated. This module will be removed on ver 0.6.0.
"""

import volkanic


class GlobalInterface(volkanic.GlobalInterface):
    package_name = 'joker.flasky'


__all__ = []
